@@ -5,12 +5,13 @@ use warnings;
 
 # Added by eilara as hack around caller() core dump
 # NOTE: Now we've switched to Sub::Uplevel can this be removed? --ADAMK
-use Carp::Heavy    (); 
-use Carp           ();
-use Sub::Uplevel   ();
-use Aspect::Advice ();
+use Carp::Heavy           (); 
+use Carp                  ();
+use Sub::Uplevel          ();
+use Aspect::Advice        ();
+use Aspect::AdviceContext ();
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -20,6 +21,7 @@ sub _install {
 	my $self     = shift;
 	my $pointcut = $self->pointcut;
 	my $code     = $self->code;
+	my $forever  = $self->forever;
 
 	# Get the curried version of the pointcut we will use for the
 	# runtime checks instead of the original.
@@ -36,7 +38,10 @@ sub _install {
 	# past the hook as quickely as possible.
 	# This flag is shared between all the generated hooks for each
 	# installed Aspect.
+	# If the advice is going to last forever then we don't need to
+	# check or use the $out_of_scope variable.
 	my $out_of_scope = undef;
+	my $MATCH_DISABLED = $forever ? '0' : '$out_of_scope';
 
 	# Find all pointcuts that are statically matched
 	# wrap the method with advice code and install the wrapper
@@ -57,10 +62,8 @@ sub _install {
 		no warnings 'redefine';
 		eval <<"END_PERL"; die $@ if $@;
 		*$NAME = sub $PROTOTYPE {
-			if ( \$out_of_scope ) {
-				# Lexical Aspect is out of scope
-				goto &\$original;
-			}
+			# Is this a lexically scoped hook that has finished
+			goto &\$original if $MATCH_DISABLED;
 
 			my \$runtime   = {};
 			my \$wantarray = wantarray;
@@ -144,6 +147,9 @@ sub _install {
 END_PERL
 	}
 
+	# If this will run forever we don't need a descoping hook
+	return if $forever;
+
 	# Return the lexical descoping hook.
 	# This MUST be stored and run at DESTROY-time by the
 	# parent object calling _install. This is less bullet-proof
