@@ -3,11 +3,9 @@ package Aspect::Library::Listenable::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.97_06';
-
 sub new {
 	my $class = shift;
-	bless { @_ }, $class;
+	return bless { @_ }, $class;
 }
 
 sub AUTOLOAD {
